[libdvbpsi-devel] [PATCH 2/2] Fix spelling of "writing"

Sebastian Ramacher sramacher at debian.org
Sat Jan 2 22:05:20 CET 2016


---
 examples/dvbinfo/dvbinfo.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/examples/dvbinfo/dvbinfo.c b/examples/dvbinfo/dvbinfo.c
index 657fd35..3cdfeba 100644
--- a/examples/dvbinfo/dvbinfo.c
+++ b/examples/dvbinfo/dvbinfo.c
@@ -390,13 +390,13 @@ static int dvbinfo_process(dvbinfo_capture_t *capture)
             if (size < 0) /* error writing */
             {
                 libdvbpsi_log(param, DVBINFO_LOG_ERROR,
-                              "error (%d) writting to %s\n", errno, param->output);
+                              "error (%d) writing to %s\n", errno, param->output);
                 break;
             }
-            else if ((size_t)size < buffer->i_size) /* short writting disk full? */
+            else if ((size_t)size < buffer->i_size) /* short writing disk full? */
             {
                 libdvbpsi_log(param, DVBINFO_LOG_ERROR,
-                              "error writting to %s (disk full?)\n", param->output);
+                              "error writing to %s (disk full?)\n", param->output);
                 break;
             }
         }
-- 
2.6.4



More information about the libdvbpsi-devel mailing list